| Title: | 'stb' Image C/C++ Header Files |
|---|---|
| Description: | Provides image-related C/C++ header files from the 'stb' single-file libraries for image loading, writing, and resizing. |
| Authors: | Tyler Morgan-Wall [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-3131-3814>), Sean Barrett [aut, cph], Jeff Roberts [aut], Jorge L. Rodriguez [aut] |
| Maintainer: | Tyler Morgan-Wall <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-09 19:29:52 UTC |
| Source: | https://github.com/cran/stbimageheaders |
Provides selected image-related C/C++ header files from stb.
To use these headers from another R package, add this to DESCRIPTION:
LinkingTo: stbimageheaders
and include the headers in C or C++ code with:
#include <stbimageheaders/stb_image.h> #include <stbimageheaders/stb_image_resize2.h> #include <stbimageheaders/stb_image_write.h>
In exactly one translation unit, define the implementation macro before including each implementation header:
#define STB_IMAGE_IMPLEMENTATION #include <stbimageheaders/stb_image.h> #define STB_IMAGE_RESIZE_IMPLEMENTATION #include <stbimageheaders/stb_image_resize2.h> #define STB_IMAGE_WRITE_IMPLEMENTATION #include <stbimageheaders/stb_image_write.h>