| Type: | Package |
| Title: | 'stb' Image C/C++ Header Files |
| Version: | 0.1.0 |
| Description: | Provides image-related C/C++ header files from the 'stb' single-file libraries for image loading, writing, and resizing. |
| License: | MIT + file LICENSE |
| URL: | https://github.com/tylermorganwall/stbimageheaders |
| BugReports: | https://github.com/tylermorganwall/stbimageheaders/issues |
| Encoding: | UTF-8 |
| NeedsCompilation: | no |
| Packaged: | 2026-06-05 02:24:39 UTC; tyler |
| Author: | Tyler Morgan-Wall |
| Maintainer: | Tyler Morgan-Wall <tylermw@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-06-09 16:10:07 UTC |
'stb' Image C/C++ Header Files
Description
Provides selected image-related C/C++ header files from stb.
Details
To use these headers from another R package, add this to DESCRIPTION:
LinkingTo: stbimageheaders
and include the headers in C or C++ code with:
#include <stbimageheaders/stb_image.h> #include <stbimageheaders/stb_image_resize2.h> #include <stbimageheaders/stb_image_write.h>
In exactly one translation unit, define the implementation macro before including each implementation header:
#define STB_IMAGE_IMPLEMENTATION #include <stbimageheaders/stb_image.h> #define STB_IMAGE_RESIZE_IMPLEMENTATION #include <stbimageheaders/stb_image_resize2.h> #define STB_IMAGE_WRITE_IMPLEMENTATION #include <stbimageheaders/stb_image_write.h>